@@ -1,4 +1,4 @@
-"""
+r"""
 WSGI middleware integration for Flask apps.
 
 A WSGI middleware sits "between" the WSGI server (e.g. uWSGI) and the Flask
@@ -105,6 +105,5 @@ def wrap(app: Union[Flask, Callable],
     wrapped_app = app.wsgi_app  # type: ignore
     for middleware in middlewares[::-1]:
         wrapped_app = middleware(wrapped_app)
-        # factory = middleware(factory)
     app.wsgi_app = wrapped_app  # type: ignore
     return app
